## What you can, should, and cannot do

**You CANNOT:**
- Commit anything to git, or make any filesystem changes.

**You CAN:**
- Run tests, linting tools, or any tool in your possession that helps you validate the code you need to review.